function opti = getOptimizer(Sys, opts)
% GETOPTIMIZER LMI CJSR problem
%
% Builds the LMI's (as Yalmip's optimizer object) used to compute the
% Lyapunov quadratic norm.
%
% It builds this problem
% 
% P(gamma) = min 0
%             Qi > 0                                        for all i in Nodes (SDP sense)
%            s.t. Ms' Qj Ms <= gamma^(2 nLabels(k)) Qi      for all (i, j, k) in Edges (SDP sense). 
%
% This is an internal private function
% Relevant when using cjsrQuadMultinorn with option 'quad.modeling' =
% 'yalmip'.

if nargin == 1
    opts = cjsrSettings() ;
end

cntr = [] ;
Q = cell(Sys.getNNodes(), 1) ;
s = Sys.getMatSize() ;
gamma = sdpvar(1, 1, 'full') ;

% Strict positivity constraint
for n = 1:Sys.getNNodes()
    Q{n} = sdpvar(s, s) ;
    cntr = [cntr ; Q{n} >= eye(s)] ;
end
    
% Norm constraint
for e = 1:Sys.getNEdges()
    edge = Sys.getEdges(e) ;
    cntr_ijs = - Sys.getMatProdEdge(e)' * Q{edge(2)} * Sys.getMatProdEdge(e) + (gamma^(2*Sys.getNLabels(e))) * Q{edge(1)} >= 0 ;
    cntr = [cntr ; cntr_ijs] ;
end

% Build optimizer
opti = optimizer(cntr, [], opts.quad.yalmip, gamma, Q) ;

end